@@ -23,53 +23,47 @@ from aliyunsdkopensearch.endpoint import endpoint_data
 class ListAppGroupsRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'OpenSearch', '2017-12-25', 'ListAppGroups','opensearch')
+		RoaRequest.__init__(self, 'OpenSearch', '2017-12-25', 'ListAppGroups')
 		self.set_uri_pattern('/v4/openapi/app-groups')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_resourceGroupId(self):
+	def get_resourceGroupId(self): # String
 		return self.get_query_params().get('resourceGroupId')
 
-	def set_resourceGroupId(self,resourceGroupId):
-		self.add_query_param('resourceGroupId',resourceGroupId)
-
-	def get_instanceId(self):
+	def set_resourceGroupId(self, resourceGroupId):  # String
+		self.add_query_param('resourceGroupId', resourceGroupId)
+	def get_instanceId(self): # String
 		return self.get_query_params().get('instanceId')
 
-	def set_instanceId(self,instanceId):
-		self.add_query_param('instanceId',instanceId)
-
-	def get_pageSize(self):
+	def set_instanceId(self, instanceId):  # String
+		self.add_query_param('instanceId', instanceId)
+	def get_pageSize(self): # Integer
 		return self.get_query_params().get('pageSize')
 
-	def set_pageSize(self,pageSize):
-		self.add_query_param('pageSize',pageSize)
-
-	def get_name(self):
+	def set_pageSize(self, pageSize):  # Integer
+		self.add_query_param('pageSize', pageSize)
+	def get_name(self): # String
 		return self.get_query_params().get('name')
 
-	def set_name(self,name):
-		self.add_query_param('name',name)
-
-	def get_sortBy(self):
+	def set_name(self, name):  # String
+		self.add_query_param('name', name)
+	def get_sortBy(self): # Integer
 		return self.get_query_params().get('sortBy')
 
-	def set_sortBy(self,sortBy):
-		self.add_query_param('sortBy',sortBy)
-
-	def get_type(self):
+	def set_sortBy(self, sortBy):  # Integer
+		self.add_query_param('sortBy', sortBy)
+	def get_type(self): # String
 		return self.get_query_params().get('type')
 
-	def set_type(self,type):
-		self.add_query_param('type',type)
-
-	def get_pageNumber(self):
+	def set_type(self, type):  # String
+		self.add_query_param('type', type)
+	def get_pageNumber(self): # Integer
 		return self.get_query_params().get('pageNumber')
 
-	def set_pageNumber(self,pageNumber):
-		self.add_query_param('pageNumber',pageNumber)
\ No newline at end of file
+	def set_pageNumber(self, pageNumber):  # Integer
+		self.add_query_param('pageNumber', pageNumber)
